summaryrefslogtreecommitdiffstats
path: root/example/example_factory.cc
diff options
context:
space:
mode:
Diffstat (limited to 'example/example_factory.cc')
-rw-r--r--example/example_factory.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/example/example_factory.cc b/example/example_factory.cc
index e3b46cf3..eaba7ee4 100644
--- a/example/example_factory.cc
+++ b/example/example_factory.cc
@@ -30,8 +30,8 @@ K_EXPORT_COMPONENT_FACTORY( libexamplepart, ExampleFactory )
KInstance* ExampleFactory::s_global = 0L;
KAboutData* ExampleFactory::s_aboutData = 0L;
-ExampleFactory::ExampleFactory( QObject* parent, const char* name )
- : KoFactory( parent, name )
+ExampleFactory::ExampleFactory( TQObject* tqparent, const char* name )
+ : KoFactory( tqparent, name )
{
global();
}
@@ -44,14 +44,14 @@ ExampleFactory::~ExampleFactory()
s_global = 0L;
}
-KParts::Part* ExampleFactory::createPartObject( QWidget *parentWidget, const char *widgetName, QObject* parent, const char* name, const char* classname, const QStringList & )
+KParts::Part* ExampleFactory::createPartObject( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & )
{
// If classname is "KoDocument", our host is a koffice application
// otherwise, the host wants us as a simple part, so switch to readonly and single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- // parentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
- ExamplePart *part = new ExamplePart( parentWidget, widgetName, parent, name, !bWantKoDocument );
+ // tqparentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
+ ExamplePart *part = new ExamplePart( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
if ( !bWantKoDocument )
part->setReadWrite( false );